# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class ImageProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'cloud_init': 'str',

        'cpu_hot_plug': 'bool',

        'cpu_hot_unplug': 'bool',

        'description': 'str',

        'disc_scsi_hot_plug': 'bool',

        'disc_scsi_hot_unplug': 'bool',

        'disc_virtio_hot_plug': 'bool',

        'disc_virtio_hot_unplug': 'bool',

        'image_aliases': 'list[str]',

        'image_type': 'str',

        'licence_type': 'str',

        'location': 'str',

        'name': 'str',

        'nic_hot_plug': 'bool',

        'nic_hot_unplug': 'bool',

        'public': 'bool',

        'ram_hot_plug': 'bool',

        'ram_hot_unplug': 'bool',

        'size': 'float',
    }

    attribute_map = {

        'cloud_init': 'cloudInit',

        'cpu_hot_plug': 'cpuHotPlug',

        'cpu_hot_unplug': 'cpuHotUnplug',

        'description': 'description',

        'disc_scsi_hot_plug': 'discScsiHotPlug',

        'disc_scsi_hot_unplug': 'discScsiHotUnplug',

        'disc_virtio_hot_plug': 'discVirtioHotPlug',

        'disc_virtio_hot_unplug': 'discVirtioHotUnplug',

        'image_aliases': 'imageAliases',

        'image_type': 'imageType',

        'licence_type': 'licenceType',

        'location': 'location',

        'name': 'name',

        'nic_hot_plug': 'nicHotPlug',

        'nic_hot_unplug': 'nicHotUnplug',

        'public': 'public',

        'ram_hot_plug': 'ramHotPlug',

        'ram_hot_unplug': 'ramHotUnplug',

        'size': 'size',
    }

    def __init__(self, cloud_init=None, cpu_hot_plug=None, cpu_hot_unplug=None, description=None, disc_scsi_hot_plug=None, disc_scsi_hot_unplug=None, disc_virtio_hot_plug=None, disc_virtio_hot_unplug=None, image_aliases=None, image_type=None, licence_type=None, location=None, name=None, nic_hot_plug=None, nic_hot_unplug=None, public=None, ram_hot_plug=None, ram_hot_unplug=None, size=None, local_vars_configuration=None):  # noqa: E501
        """ImageProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cloud_init = None
        self._cpu_hot_plug = None
        self._cpu_hot_unplug = None
        self._description = None
        self._disc_scsi_hot_plug = None
        self._disc_scsi_hot_unplug = None
        self._disc_virtio_hot_plug = None
        self._disc_virtio_hot_unplug = None
        self._image_aliases = None
        self._image_type = None
        self._licence_type = None
        self._location = None
        self._name = None
        self._nic_hot_plug = None
        self._nic_hot_unplug = None
        self._public = None
        self._ram_hot_plug = None
        self._ram_hot_unplug = None
        self._size = None
        self.discriminator = None

        if cloud_init is not None:
            self.cloud_init = cloud_init
        if cpu_hot_plug is not None:
            self.cpu_hot_plug = cpu_hot_plug
        if cpu_hot_unplug is not None:
            self.cpu_hot_unplug = cpu_hot_unplug
        if description is not None:
            self.description = description
        if disc_scsi_hot_plug is not None:
            self.disc_scsi_hot_plug = disc_scsi_hot_plug
        if disc_scsi_hot_unplug is not None:
            self.disc_scsi_hot_unplug = disc_scsi_hot_unplug
        if disc_virtio_hot_plug is not None:
            self.disc_virtio_hot_plug = disc_virtio_hot_plug
        if disc_virtio_hot_unplug is not None:
            self.disc_virtio_hot_unplug = disc_virtio_hot_unplug
        if image_aliases is not None:
            self.image_aliases = image_aliases
        if image_type is not None:
            self.image_type = image_type
        self.licence_type = licence_type
        if location is not None:
            self.location = location
        if name is not None:
            self.name = name
        if nic_hot_plug is not None:
            self.nic_hot_plug = nic_hot_plug
        if nic_hot_unplug is not None:
            self.nic_hot_unplug = nic_hot_unplug
        if public is not None:
            self.public = public
        if ram_hot_plug is not None:
            self.ram_hot_plug = ram_hot_plug
        if ram_hot_unplug is not None:
            self.ram_hot_unplug = ram_hot_unplug
        if size is not None:
            self.size = size


    @property
    def cloud_init(self):
        """Gets the cloud_init of this ImageProperties.  # noqa: E501

        Cloud init compatibility.  # noqa: E501

        :return: The cloud_init of this ImageProperties.  # noqa: E501
        :rtype: str
        """
        return self._cloud_init

    @cloud_init.setter
    def cloud_init(self, cloud_init):
        """Sets the cloud_init of this ImageProperties.

        Cloud init compatibility.  # noqa: E501

        :param cloud_init: The cloud_init of this ImageProperties.  # noqa: E501
        :type cloud_init: str
        """
        allowed_values = ["NONE", "V1"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and cloud_init not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `cloud_init` ({0}), must be one of {1}"  # noqa: E501
                .format(cloud_init, allowed_values)
            )

        self._cloud_init = cloud_init

    @property
    def cpu_hot_plug(self):
        """Gets the cpu_hot_plug of this ImageProperties.  # noqa: E501

        Hot-plug capable CPU (no reboot required).  # noqa: E501

        :return: The cpu_hot_plug of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._cpu_hot_plug

    @cpu_hot_plug.setter
    def cpu_hot_plug(self, cpu_hot_plug):
        """Sets the cpu_hot_plug of this ImageProperties.

        Hot-plug capable CPU (no reboot required).  # noqa: E501

        :param cpu_hot_plug: The cpu_hot_plug of this ImageProperties.  # noqa: E501
        :type cpu_hot_plug: bool
        """

        self._cpu_hot_plug = cpu_hot_plug

    @property
    def cpu_hot_unplug(self):
        """Gets the cpu_hot_unplug of this ImageProperties.  # noqa: E501

        Hot-unplug capable CPU (no reboot required).  # noqa: E501

        :return: The cpu_hot_unplug of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._cpu_hot_unplug

    @cpu_hot_unplug.setter
    def cpu_hot_unplug(self, cpu_hot_unplug):
        """Sets the cpu_hot_unplug of this ImageProperties.

        Hot-unplug capable CPU (no reboot required).  # noqa: E501

        :param cpu_hot_unplug: The cpu_hot_unplug of this ImageProperties.  # noqa: E501
        :type cpu_hot_unplug: bool
        """

        self._cpu_hot_unplug = cpu_hot_unplug

    @property
    def description(self):
        """Gets the description of this ImageProperties.  # noqa: E501

        Human-readable description.  # noqa: E501

        :return: The description of this ImageProperties.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ImageProperties.

        Human-readable description.  # noqa: E501

        :param description: The description of this ImageProperties.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def disc_scsi_hot_plug(self):
        """Gets the disc_scsi_hot_plug of this ImageProperties.  # noqa: E501

        Hot-plug capable SCSI drive (no reboot required).  # noqa: E501

        :return: The disc_scsi_hot_plug of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._disc_scsi_hot_plug

    @disc_scsi_hot_plug.setter
    def disc_scsi_hot_plug(self, disc_scsi_hot_plug):
        """Sets the disc_scsi_hot_plug of this ImageProperties.

        Hot-plug capable SCSI drive (no reboot required).  # noqa: E501

        :param disc_scsi_hot_plug: The disc_scsi_hot_plug of this ImageProperties.  # noqa: E501
        :type disc_scsi_hot_plug: bool
        """

        self._disc_scsi_hot_plug = disc_scsi_hot_plug

    @property
    def disc_scsi_hot_unplug(self):
        """Gets the disc_scsi_hot_unplug of this ImageProperties.  # noqa: E501

        Hot-unplug capable SCSI drive (no reboot required). Not supported with Windows VMs.  # noqa: E501

        :return: The disc_scsi_hot_unplug of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._disc_scsi_hot_unplug

    @disc_scsi_hot_unplug.setter
    def disc_scsi_hot_unplug(self, disc_scsi_hot_unplug):
        """Sets the disc_scsi_hot_unplug of this ImageProperties.

        Hot-unplug capable SCSI drive (no reboot required). Not supported with Windows VMs.  # noqa: E501

        :param disc_scsi_hot_unplug: The disc_scsi_hot_unplug of this ImageProperties.  # noqa: E501
        :type disc_scsi_hot_unplug: bool
        """

        self._disc_scsi_hot_unplug = disc_scsi_hot_unplug

    @property
    def disc_virtio_hot_plug(self):
        """Gets the disc_virtio_hot_plug of this ImageProperties.  # noqa: E501

        Hot-plug capable Virt-IO drive (no reboot required).  # noqa: E501

        :return: The disc_virtio_hot_plug of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._disc_virtio_hot_plug

    @disc_virtio_hot_plug.setter
    def disc_virtio_hot_plug(self, disc_virtio_hot_plug):
        """Sets the disc_virtio_hot_plug of this ImageProperties.

        Hot-plug capable Virt-IO drive (no reboot required).  # noqa: E501

        :param disc_virtio_hot_plug: The disc_virtio_hot_plug of this ImageProperties.  # noqa: E501
        :type disc_virtio_hot_plug: bool
        """

        self._disc_virtio_hot_plug = disc_virtio_hot_plug

    @property
    def disc_virtio_hot_unplug(self):
        """Gets the disc_virtio_hot_unplug of this ImageProperties.  # noqa: E501

        Hot-unplug capable Virt-IO drive (no reboot required). Not supported with Windows VMs.  # noqa: E501

        :return: The disc_virtio_hot_unplug of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._disc_virtio_hot_unplug

    @disc_virtio_hot_unplug.setter
    def disc_virtio_hot_unplug(self, disc_virtio_hot_unplug):
        """Sets the disc_virtio_hot_unplug of this ImageProperties.

        Hot-unplug capable Virt-IO drive (no reboot required). Not supported with Windows VMs.  # noqa: E501

        :param disc_virtio_hot_unplug: The disc_virtio_hot_unplug of this ImageProperties.  # noqa: E501
        :type disc_virtio_hot_unplug: bool
        """

        self._disc_virtio_hot_unplug = disc_virtio_hot_unplug

    @property
    def image_aliases(self):
        """Gets the image_aliases of this ImageProperties.  # noqa: E501

        List of image aliases mapped for this image  # noqa: E501

        :return: The image_aliases of this ImageProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._image_aliases

    @image_aliases.setter
    def image_aliases(self, image_aliases):
        """Sets the image_aliases of this ImageProperties.

        List of image aliases mapped for this image  # noqa: E501

        :param image_aliases: The image_aliases of this ImageProperties.  # noqa: E501
        :type image_aliases: list[str]
        """

        self._image_aliases = image_aliases

    @property
    def image_type(self):
        """Gets the image_type of this ImageProperties.  # noqa: E501

        The image type.  # noqa: E501

        :return: The image_type of this ImageProperties.  # noqa: E501
        :rtype: str
        """
        return self._image_type

    @image_type.setter
    def image_type(self, image_type):
        """Sets the image_type of this ImageProperties.

        The image type.  # noqa: E501

        :param image_type: The image_type of this ImageProperties.  # noqa: E501
        :type image_type: str
        """
        allowed_values = ["HDD", "CDROM", "UNKNOWN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and image_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `image_type` ({0}), must be one of {1}"  # noqa: E501
                .format(image_type, allowed_values)
            )

        self._image_type = image_type

    @property
    def licence_type(self):
        """Gets the licence_type of this ImageProperties.  # noqa: E501

        The OS type of this image.  # noqa: E501

        :return: The licence_type of this ImageProperties.  # noqa: E501
        :rtype: str
        """
        return self._licence_type

    @licence_type.setter
    def licence_type(self, licence_type):
        """Sets the licence_type of this ImageProperties.

        The OS type of this image.  # noqa: E501

        :param licence_type: The licence_type of this ImageProperties.  # noqa: E501
        :type licence_type: str
        """
        if self.local_vars_configuration.client_side_validation and licence_type is None:  # noqa: E501
            raise ValueError("Invalid value for `licence_type`, must not be `None`")  # noqa: E501
        allowed_values = ["UNKNOWN", "WINDOWS", "WINDOWS2016", "WINDOWS2022", "RHEL", "LINUX", "OTHER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and licence_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `licence_type` ({0}), must be one of {1}"  # noqa: E501
                .format(licence_type, allowed_values)
            )

        self._licence_type = licence_type

    @property
    def location(self):
        """Gets the location of this ImageProperties.  # noqa: E501

        The location of this image/snapshot.  # noqa: E501

        :return: The location of this ImageProperties.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ImageProperties.

        The location of this image/snapshot.  # noqa: E501

        :param location: The location of this ImageProperties.  # noqa: E501
        :type location: str
        """

        self._location = location

    @property
    def name(self):
        """Gets the name of this ImageProperties.  # noqa: E501

        The resource name.  # noqa: E501

        :return: The name of this ImageProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ImageProperties.

        The resource name.  # noqa: E501

        :param name: The name of this ImageProperties.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def nic_hot_plug(self):
        """Gets the nic_hot_plug of this ImageProperties.  # noqa: E501

        Hot-plug capable NIC (no reboot required).  # noqa: E501

        :return: The nic_hot_plug of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._nic_hot_plug

    @nic_hot_plug.setter
    def nic_hot_plug(self, nic_hot_plug):
        """Sets the nic_hot_plug of this ImageProperties.

        Hot-plug capable NIC (no reboot required).  # noqa: E501

        :param nic_hot_plug: The nic_hot_plug of this ImageProperties.  # noqa: E501
        :type nic_hot_plug: bool
        """

        self._nic_hot_plug = nic_hot_plug

    @property
    def nic_hot_unplug(self):
        """Gets the nic_hot_unplug of this ImageProperties.  # noqa: E501

        Hot-unplug capable NIC (no reboot required).  # noqa: E501

        :return: The nic_hot_unplug of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._nic_hot_unplug

    @nic_hot_unplug.setter
    def nic_hot_unplug(self, nic_hot_unplug):
        """Sets the nic_hot_unplug of this ImageProperties.

        Hot-unplug capable NIC (no reboot required).  # noqa: E501

        :param nic_hot_unplug: The nic_hot_unplug of this ImageProperties.  # noqa: E501
        :type nic_hot_unplug: bool
        """

        self._nic_hot_unplug = nic_hot_unplug

    @property
    def public(self):
        """Gets the public of this ImageProperties.  # noqa: E501

        Indicates whether the image is part of a public repository.  # noqa: E501

        :return: The public of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this ImageProperties.

        Indicates whether the image is part of a public repository.  # noqa: E501

        :param public: The public of this ImageProperties.  # noqa: E501
        :type public: bool
        """

        self._public = public

    @property
    def ram_hot_plug(self):
        """Gets the ram_hot_plug of this ImageProperties.  # noqa: E501

        Hot-plug capable RAM (no reboot required).  # noqa: E501

        :return: The ram_hot_plug of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._ram_hot_plug

    @ram_hot_plug.setter
    def ram_hot_plug(self, ram_hot_plug):
        """Sets the ram_hot_plug of this ImageProperties.

        Hot-plug capable RAM (no reboot required).  # noqa: E501

        :param ram_hot_plug: The ram_hot_plug of this ImageProperties.  # noqa: E501
        :type ram_hot_plug: bool
        """

        self._ram_hot_plug = ram_hot_plug

    @property
    def ram_hot_unplug(self):
        """Gets the ram_hot_unplug of this ImageProperties.  # noqa: E501

        Hot-unplug capable RAM (no reboot required).  # noqa: E501

        :return: The ram_hot_unplug of this ImageProperties.  # noqa: E501
        :rtype: bool
        """
        return self._ram_hot_unplug

    @ram_hot_unplug.setter
    def ram_hot_unplug(self, ram_hot_unplug):
        """Sets the ram_hot_unplug of this ImageProperties.

        Hot-unplug capable RAM (no reboot required).  # noqa: E501

        :param ram_hot_unplug: The ram_hot_unplug of this ImageProperties.  # noqa: E501
        :type ram_hot_unplug: bool
        """

        self._ram_hot_unplug = ram_hot_unplug

    @property
    def size(self):
        """Gets the size of this ImageProperties.  # noqa: E501

        The image size in GB.  # noqa: E501

        :return: The size of this ImageProperties.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ImageProperties.

        The image size in GB.  # noqa: E501

        :param size: The size of this ImageProperties.  # noqa: E501
        :type size: float
        """

        self._size = size
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImageProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImageProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class KubernetesNodeProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'k8s_version': 'str',

        'name': 'str',

        'private_ip': 'str',

        'public_ip': 'str',
    }

    attribute_map = {

        'k8s_version': 'k8sVersion',

        'name': 'name',

        'private_ip': 'privateIP',

        'public_ip': 'publicIP',
    }

    def __init__(self, k8s_version=None, name=None, private_ip=None, public_ip=None, local_vars_configuration=None):  # noqa: E501
        """KubernetesNodeProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._k8s_version = None
        self._name = None
        self._private_ip = None
        self._public_ip = None
        self.discriminator = None

        self.k8s_version = k8s_version
        self.name = name
        if private_ip is not None:
            self.private_ip = private_ip
        if public_ip is not None:
            self.public_ip = public_ip


    @property
    def k8s_version(self):
        """Gets the k8s_version of this KubernetesNodeProperties.  # noqa: E501

        The Kubernetes version running in the node pool. Note that this imposes restrictions on which Kubernetes versions can run in the node pools of a cluster. Also, not all Kubernetes versions are suitable upgrade targets for all earlier versions.  # noqa: E501

        :return: The k8s_version of this KubernetesNodeProperties.  # noqa: E501
        :rtype: str
        """
        return self._k8s_version

    @k8s_version.setter
    def k8s_version(self, k8s_version):
        """Sets the k8s_version of this KubernetesNodeProperties.

        The Kubernetes version running in the node pool. Note that this imposes restrictions on which Kubernetes versions can run in the node pools of a cluster. Also, not all Kubernetes versions are suitable upgrade targets for all earlier versions.  # noqa: E501

        :param k8s_version: The k8s_version of this KubernetesNodeProperties.  # noqa: E501
        :type k8s_version: str
        """
        if self.local_vars_configuration.client_side_validation and k8s_version is None:  # noqa: E501
            raise ValueError("Invalid value for `k8s_version`, must not be `None`")  # noqa: E501

        self._k8s_version = k8s_version

    @property
    def name(self):
        """Gets the name of this KubernetesNodeProperties.  # noqa: E501

        The Kubernetes node name.  # noqa: E501

        :return: The name of this KubernetesNodeProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this KubernetesNodeProperties.

        The Kubernetes node name.  # noqa: E501

        :param name: The name of this KubernetesNodeProperties.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def private_ip(self):
        """Gets the private_ip of this KubernetesNodeProperties.  # noqa: E501

        The private IP associated with the node.  # noqa: E501

        :return: The private_ip of this KubernetesNodeProperties.  # noqa: E501
        :rtype: str
        """
        return self._private_ip

    @private_ip.setter
    def private_ip(self, private_ip):
        """Sets the private_ip of this KubernetesNodeProperties.

        The private IP associated with the node.  # noqa: E501

        :param private_ip: The private_ip of this KubernetesNodeProperties.  # noqa: E501
        :type private_ip: str
        """

        self._private_ip = private_ip

    @property
    def public_ip(self):
        """Gets the public_ip of this KubernetesNodeProperties.  # noqa: E501

        The public IP associated with the node.  # noqa: E501

        :return: The public_ip of this KubernetesNodeProperties.  # noqa: E501
        :rtype: str
        """
        return self._public_ip

    @public_ip.setter
    def public_ip(self, public_ip):
        """Sets the public_ip of this KubernetesNodeProperties.

        The public IP associated with the node.  # noqa: E501

        :param public_ip: The public_ip of this KubernetesNodeProperties.  # noqa: E501
        :type public_ip: str
        """

        self._public_ip = public_ip
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KubernetesNodeProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KubernetesNodeProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup  # noqa: H301
import os
import codecs

NAME = "ionoscloud"
VERSION = "6.1.9"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil", "asn1crypto"]

here = os.path.abspath(os.path.dirname(__file__))

def read(*parts):
    return codecs.open(os.path.join(here, *parts), 'r', 'utf-8').read()

if os.path.isfile("README.md"):
    long_desc = read('README.md')
else:
    long_desc = "Ionos Cloud API Client Library for Python"

setup(
    name=NAME,
    version=VERSION,
    description="Python SDK for the Ionos Cloud API",
    author='Ionos Cloud',
    author_email='sdk@cloud.ionos.com',
    long_description=long_desc,
    long_description_content_type='text/markdown',
    url="https://github.com/ionos-cloud/ionos-cloud-sdk-python",
    keywords=["OpenAPI", "OpenAPI-Generator", "CLOUD API"],
    install_requires=REQUIRES,
    packages=['ionoscloud', 'ionoscloud.api', 'ionoscloud.models'],
    include_package_data=True,
    classifiers=[
         'Natural Language :: English',
         'Environment :: Web Environment',
         'Intended Audience :: Developers',
         'License :: OSI Approved :: Apache Software License',
         'Operating System :: POSIX',
         'Programming Language :: Python',
         'Programming Language :: Python :: 3',
         'Topic :: Software Development :: Libraries :: Python Modules',
         'Topic :: Software Development :: Libraries :: Application Frameworks',
         'Topic :: Internet :: WWW/HTTP']
)



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class IpConsumer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'datacenter_id': 'str',

        'datacenter_name': 'str',

        'ip': 'str',

        'k8s_cluster_uuid': 'str',

        'k8s_node_pool_uuid': 'str',

        'mac': 'str',

        'nic_id': 'str',

        'server_id': 'str',

        'server_name': 'str',
    }

    attribute_map = {

        'datacenter_id': 'datacenterId',

        'datacenter_name': 'datacenterName',

        'ip': 'ip',

        'k8s_cluster_uuid': 'k8sClusterUuid',

        'k8s_node_pool_uuid': 'k8sNodePoolUuid',

        'mac': 'mac',

        'nic_id': 'nicId',

        'server_id': 'serverId',

        'server_name': 'serverName',
    }

    def __init__(self, datacenter_id=None, datacenter_name=None, ip=None, k8s_cluster_uuid=None, k8s_node_pool_uuid=None, mac=None, nic_id=None, server_id=None, server_name=None, local_vars_configuration=None):  # noqa: E501
        """IpConsumer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._datacenter_id = None
        self._datacenter_name = None
        self._ip = None
        self._k8s_cluster_uuid = None
        self._k8s_node_pool_uuid = None
        self._mac = None
        self._nic_id = None
        self._server_id = None
        self._server_name = None
        self.discriminator = None

        if datacenter_id is not None:
            self.datacenter_id = datacenter_id
        if datacenter_name is not None:
            self.datacenter_name = datacenter_name
        if ip is not None:
            self.ip = ip
        if k8s_cluster_uuid is not None:
            self.k8s_cluster_uuid = k8s_cluster_uuid
        if k8s_node_pool_uuid is not None:
            self.k8s_node_pool_uuid = k8s_node_pool_uuid
        if mac is not None:
            self.mac = mac
        if nic_id is not None:
            self.nic_id = nic_id
        if server_id is not None:
            self.server_id = server_id
        if server_name is not None:
            self.server_name = server_name


    @property
    def datacenter_id(self):
        """Gets the datacenter_id of this IpConsumer.  # noqa: E501


        :return: The datacenter_id of this IpConsumer.  # noqa: E501
        :rtype: str
        """
        return self._datacenter_id

    @datacenter_id.setter
    def datacenter_id(self, datacenter_id):
        """Sets the datacenter_id of this IpConsumer.


        :param datacenter_id: The datacenter_id of this IpConsumer.  # noqa: E501
        :type datacenter_id: str
        """

        self._datacenter_id = datacenter_id

    @property
    def datacenter_name(self):
        """Gets the datacenter_name of this IpConsumer.  # noqa: E501


        :return: The datacenter_name of this IpConsumer.  # noqa: E501
        :rtype: str
        """
        return self._datacenter_name

    @datacenter_name.setter
    def datacenter_name(self, datacenter_name):
        """Sets the datacenter_name of this IpConsumer.


        :param datacenter_name: The datacenter_name of this IpConsumer.  # noqa: E501
        :type datacenter_name: str
        """

        self._datacenter_name = datacenter_name

    @property
    def ip(self):
        """Gets the ip of this IpConsumer.  # noqa: E501


        :return: The ip of this IpConsumer.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this IpConsumer.


        :param ip: The ip of this IpConsumer.  # noqa: E501
        :type ip: str
        """

        self._ip = ip

    @property
    def k8s_cluster_uuid(self):
        """Gets the k8s_cluster_uuid of this IpConsumer.  # noqa: E501


        :return: The k8s_cluster_uuid of this IpConsumer.  # noqa: E501
        :rtype: str
        """
        return self._k8s_cluster_uuid

    @k8s_cluster_uuid.setter
    def k8s_cluster_uuid(self, k8s_cluster_uuid):
        """Sets the k8s_cluster_uuid of this IpConsumer.


        :param k8s_cluster_uuid: The k8s_cluster_uuid of this IpConsumer.  # noqa: E501
        :type k8s_cluster_uuid: str
        """

        self._k8s_cluster_uuid = k8s_cluster_uuid

    @property
    def k8s_node_pool_uuid(self):
        """Gets the k8s_node_pool_uuid of this IpConsumer.  # noqa: E501


        :return: The k8s_node_pool_uuid of this IpConsumer.  # noqa: E501
        :rtype: str
        """
        return self._k8s_node_pool_uuid

    @k8s_node_pool_uuid.setter
    def k8s_node_pool_uuid(self, k8s_node_pool_uuid):
        """Sets the k8s_node_pool_uuid of this IpConsumer.


        :param k8s_node_pool_uuid: The k8s_node_pool_uuid of this IpConsumer.  # noqa: E501
        :type k8s_node_pool_uuid: str
        """

        self._k8s_node_pool_uuid = k8s_node_pool_uuid

    @property
    def mac(self):
        """Gets the mac of this IpConsumer.  # noqa: E501


        :return: The mac of this IpConsumer.  # noqa: E501
        :rtype: str
        """
        return self._mac

    @mac.setter
    def mac(self, mac):
        """Sets the mac of this IpConsumer.


        :param mac: The mac of this IpConsumer.  # noqa: E501
        :type mac: str
        """

        self._mac = mac

    @property
    def nic_id(self):
        """Gets the nic_id of this IpConsumer.  # noqa: E501


        :return: The nic_id of this IpConsumer.  # noqa: E501
        :rtype: str
        """
        return self._nic_id

    @nic_id.setter
    def nic_id(self, nic_id):
        """Sets the nic_id of this IpConsumer.


        :param nic_id: The nic_id of this IpConsumer.  # noqa: E501
        :type nic_id: str
        """

        self._nic_id = nic_id

    @property
    def server_id(self):
        """Gets the server_id of this IpConsumer.  # noqa: E501


        :return: The server_id of this IpConsumer.  # noqa: E501
        :rtype: str
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this IpConsumer.


        :param server_id: The server_id of this IpConsumer.  # noqa: E501
        :type server_id: str
        """

        self._server_id = server_id

    @property
    def server_name(self):
        """Gets the server_name of this IpConsumer.  # noqa: E501


        :return: The server_name of this IpConsumer.  # noqa: E501
        :rtype: str
        """
        return self._server_name

    @server_name.setter
    def server_name(self, server_name):
        """Sets the server_name of this IpConsumer.


        :param server_name: The server_name of this IpConsumer.  # noqa: E501
        :type server_name: str
        """

        self._server_name = server_name
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IpConsumer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IpConsumer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class NetworkLoadBalancerProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'ips': 'list[str]',

        'lb_private_ips': 'list[str]',

        'listener_lan': 'int',

        'name': 'str',

        'target_lan': 'int',
    }

    attribute_map = {

        'ips': 'ips',

        'lb_private_ips': 'lbPrivateIps',

        'listener_lan': 'listenerLan',

        'name': 'name',

        'target_lan': 'targetLan',
    }

    def __init__(self, ips=None, lb_private_ips=None, listener_lan=None, name=None, target_lan=None, local_vars_configuration=None):  # noqa: E501
        """NetworkLoadBalancerProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ips = None
        self._lb_private_ips = None
        self._listener_lan = None
        self._name = None
        self._target_lan = None
        self.discriminator = None

        if ips is not None:
            self.ips = ips
        if lb_private_ips is not None:
            self.lb_private_ips = lb_private_ips
        self.listener_lan = listener_lan
        self.name = name
        self.target_lan = target_lan


    @property
    def ips(self):
        """Gets the ips of this NetworkLoadBalancerProperties.  # noqa: E501

        Collection of the Network Load Balancer IP addresses. (Inbound and outbound) IPs of the listenerLan must be customer-reserved IPs for public Load Balancers, and private IPs for private Load Balancers.  # noqa: E501

        :return: The ips of this NetworkLoadBalancerProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._ips

    @ips.setter
    def ips(self, ips):
        """Sets the ips of this NetworkLoadBalancerProperties.

        Collection of the Network Load Balancer IP addresses. (Inbound and outbound) IPs of the listenerLan must be customer-reserved IPs for public Load Balancers, and private IPs for private Load Balancers.  # noqa: E501

        :param ips: The ips of this NetworkLoadBalancerProperties.  # noqa: E501
        :type ips: list[str]
        """

        self._ips = ips

    @property
    def lb_private_ips(self):
        """Gets the lb_private_ips of this NetworkLoadBalancerProperties.  # noqa: E501

        Collection of private IP addresses with subnet mask of the Network Load Balancer. IPs must contain a valid subnet mask. If no IP is provided, the system will generate an IP with /24 subnet.  # noqa: E501

        :return: The lb_private_ips of this NetworkLoadBalancerProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._lb_private_ips

    @lb_private_ips.setter
    def lb_private_ips(self, lb_private_ips):
        """Sets the lb_private_ips of this NetworkLoadBalancerProperties.

        Collection of private IP addresses with subnet mask of the Network Load Balancer. IPs must contain a valid subnet mask. If no IP is provided, the system will generate an IP with /24 subnet.  # noqa: E501

        :param lb_private_ips: The lb_private_ips of this NetworkLoadBalancerProperties.  # noqa: E501
        :type lb_private_ips: list[str]
        """

        self._lb_private_ips = lb_private_ips

    @property
    def listener_lan(self):
        """Gets the listener_lan of this NetworkLoadBalancerProperties.  # noqa: E501

        ID of the listening LAN (inbound).  # noqa: E501

        :return: The listener_lan of this NetworkLoadBalancerProperties.  # noqa: E501
        :rtype: int
        """
        return self._listener_lan

    @listener_lan.setter
    def listener_lan(self, listener_lan):
        """Sets the listener_lan of this NetworkLoadBalancerProperties.

        ID of the listening LAN (inbound).  # noqa: E501

        :param listener_lan: The listener_lan of this NetworkLoadBalancerProperties.  # noqa: E501
        :type listener_lan: int
        """
        if self.local_vars_configuration.client_side_validation and listener_lan is None:  # noqa: E501
            raise ValueError("Invalid value for `listener_lan`, must not be `None`")  # noqa: E501

        self._listener_lan = listener_lan

    @property
    def name(self):
        """Gets the name of this NetworkLoadBalancerProperties.  # noqa: E501

        The name of the Network Load Balancer.  # noqa: E501

        :return: The name of this NetworkLoadBalancerProperties.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NetworkLoadBalancerProperties.

        The name of the Network Load Balancer.  # noqa: E501

        :param name: The name of this NetworkLoadBalancerProperties.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def target_lan(self):
        """Gets the target_lan of this NetworkLoadBalancerProperties.  # noqa: E501

        ID of the balanced private target LAN (outbound).  # noqa: E501

        :return: The target_lan of this NetworkLoadBalancerProperties.  # noqa: E501
        :rtype: int
        """
        return self._target_lan

    @target_lan.setter
    def target_lan(self, target_lan):
        """Sets the target_lan of this NetworkLoadBalancerProperties.

        ID of the balanced private target LAN (outbound).  # noqa: E501

        :param target_lan: The target_lan of this NetworkLoadBalancerProperties.  # noqa: E501
        :type target_lan: int
        """
        if self.local_vars_configuration.client_side_validation and target_lan is None:  # noqa: E501
            raise ValueError("Invalid value for `target_lan`, must not be `None`")  # noqa: E501

        self._target_lan = target_lan
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkLoadBalancerProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NetworkLoadBalancerProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CLOUD API

    IONOS Enterprise-grade Infrastructure as a Service (IaaS) solutions can be managed through the Cloud API, in addition or as an alternative to the \"Data Center Designer\" (DCD) browser-based tool.    Both methods employ consistent concepts and features, deliver similar power and flexibility, and can be used to perform a multitude of management tasks, including adding servers, volumes, configuring networks, and so on.  # noqa: E501

    The version of the OpenAPI document: 6.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud.configuration import Configuration


class KubernetesNodePoolPropertiesForPost(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'annotations': 'dict(str, str)',

        'auto_scaling': 'KubernetesAutoScaling',

        'availability_zone': 'str',

        'cores_count': 'int',

        'cpu_family': 'str',

        'datacenter_id': 'str',

        'k8s_version': 'str',

        'labels': 'dict(str, str)',

        'lans': 'list[KubernetesNodePoolLan]',

        'maintenance_window': 'KubernetesMaintenanceWindow',

        'name': 'str',

        'node_count': 'int',

        'public_ips': 'list[str]',

        'ram_size': 'int',

        'storage_size': 'int',

        'storage_type': 'str',
    }

    attribute_map = {

        'annotations': 'annotations',

        'auto_scaling': 'autoScaling',

        'availability_zone': 'availabilityZone',

        'cores_count': 'coresCount',

        'cpu_family': 'cpuFamily',

        'datacenter_id': 'datacenterId',

        'k8s_version': 'k8sVersion',

        'labels': 'labels',

        'lans': 'lans',

        'maintenance_window': 'maintenanceWindow',

        'name': 'name',

        'node_count': 'nodeCount',

        'public_ips': 'publicIps',

        'ram_size': 'ramSize',

        'storage_size': 'storageSize',

        'storage_type': 'storageType',
    }

    def __init__(self, annotations=None, auto_scaling=None, availability_zone=None, cores_count=None, cpu_family=None, datacenter_id=None, k8s_version=None, labels=None, lans=None, maintenance_window=None, name=None, node_count=None, public_ips=None, ram_size=None, storage_size=None, storage_type=None, local_vars_configuration=None):  # noqa: E501
        """KubernetesNodePoolPropertiesForPost - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._annotations = None
        self._auto_scaling = None
        self._availability_zone = None
        self._cores_count = None
        self._cpu_family = None
        self._datacenter_id = None
        self._k8s_version = None
        self._labels = None
        self._lans = None
        self._maintenance_window = None
        self._name = None
        self._node_count = None
        self._public_ips = None
        self._ram_size = None
        self._storage_size = None
        self._storage_type = None
        self.discriminator = None

        if annotations is not None:
            self.annotations = annotations
        if auto_scaling is not None:
            self.auto_scaling = auto_scaling
        self.availability_zone = availability_zone
        self.cores_count = cores_count
        self.cpu_family = cpu_family
        self.datacenter_id = datacenter_id
        if k8s_version is not None:
            self.k8s_version = k8s_version
        if labels is not None:
            self.labels = labels
        if lans is not None:
            self.lans = lans
        if maintenance_window is not None:
            self.maintenance_window = maintenance_window
        self.name = name
        self.node_count = node_count
        if public_ips is not None:
            self.public_ips = public_ips
        self.ram_size = ram_size
        self.storage_size = storage_size
        self.storage_type = storage_type


    @property
    def annotations(self):
        """Gets the annotations of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The annotations attached to the node pool.  # noqa: E501

        :return: The annotations of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this KubernetesNodePoolPropertiesForPost.

        The annotations attached to the node pool.  # noqa: E501

        :param annotations: The annotations of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type annotations: dict(str, str)
        """

        self._annotations = annotations

    @property
    def auto_scaling(self):
        """Gets the auto_scaling of this KubernetesNodePoolPropertiesForPost.  # noqa: E501


        :return: The auto_scaling of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: KubernetesAutoScaling
        """
        return self._auto_scaling

    @auto_scaling.setter
    def auto_scaling(self, auto_scaling):
        """Sets the auto_scaling of this KubernetesNodePoolPropertiesForPost.


        :param auto_scaling: The auto_scaling of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type auto_scaling: KubernetesAutoScaling
        """

        self._auto_scaling = auto_scaling

    @property
    def availability_zone(self):
        """Gets the availability_zone of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The availability zone in which the target VM should be provisioned.  # noqa: E501

        :return: The availability_zone of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: str
        """
        return self._availability_zone

    @availability_zone.setter
    def availability_zone(self, availability_zone):
        """Sets the availability_zone of this KubernetesNodePoolPropertiesForPost.

        The availability zone in which the target VM should be provisioned.  # noqa: E501

        :param availability_zone: The availability_zone of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type availability_zone: str
        """
        if self.local_vars_configuration.client_side_validation and availability_zone is None:  # noqa: E501
            raise ValueError("Invalid value for `availability_zone`, must not be `None`")  # noqa: E501
        allowed_values = ["AUTO", "ZONE_1", "ZONE_2"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and availability_zone not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `availability_zone` ({0}), must be one of {1}"  # noqa: E501
                .format(availability_zone, allowed_values)
            )

        self._availability_zone = availability_zone

    @property
    def cores_count(self):
        """Gets the cores_count of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The total number of cores for the nodes.  # noqa: E501

        :return: The cores_count of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: int
        """
        return self._cores_count

    @cores_count.setter
    def cores_count(self, cores_count):
        """Sets the cores_count of this KubernetesNodePoolPropertiesForPost.

        The total number of cores for the nodes.  # noqa: E501

        :param cores_count: The cores_count of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type cores_count: int
        """
        if self.local_vars_configuration.client_side_validation and cores_count is None:  # noqa: E501
            raise ValueError("Invalid value for `cores_count`, must not be `None`")  # noqa: E501

        self._cores_count = cores_count

    @property
    def cpu_family(self):
        """Gets the cpu_family of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The CPU type for the nodes.  # noqa: E501

        :return: The cpu_family of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: str
        """
        return self._cpu_family

    @cpu_family.setter
    def cpu_family(self, cpu_family):
        """Sets the cpu_family of this KubernetesNodePoolPropertiesForPost.

        The CPU type for the nodes.  # noqa: E501

        :param cpu_family: The cpu_family of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type cpu_family: str
        """
        if self.local_vars_configuration.client_side_validation and cpu_family is None:  # noqa: E501
            raise ValueError("Invalid value for `cpu_family`, must not be `None`")  # noqa: E501

        self._cpu_family = cpu_family

    @property
    def datacenter_id(self):
        """Gets the datacenter_id of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The unique identifier of the VDC where the worker nodes of the node pool are provisioned.Note that the data center is located in the exact place where the parent cluster of the node pool is located.  # noqa: E501

        :return: The datacenter_id of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: str
        """
        return self._datacenter_id

    @datacenter_id.setter
    def datacenter_id(self, datacenter_id):
        """Sets the datacenter_id of this KubernetesNodePoolPropertiesForPost.

        The unique identifier of the VDC where the worker nodes of the node pool are provisioned.Note that the data center is located in the exact place where the parent cluster of the node pool is located.  # noqa: E501

        :param datacenter_id: The datacenter_id of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type datacenter_id: str
        """
        if self.local_vars_configuration.client_side_validation and datacenter_id is None:  # noqa: E501
            raise ValueError("Invalid value for `datacenter_id`, must not be `None`")  # noqa: E501

        self._datacenter_id = datacenter_id

    @property
    def k8s_version(self):
        """Gets the k8s_version of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The Kubernetes version running in the node pool. Note that this imposes restrictions on which Kubernetes versions can run in the node pools of a cluster. Also, not all Kubernetes versions are suitable upgrade targets for all earlier versions.  # noqa: E501

        :return: The k8s_version of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: str
        """
        return self._k8s_version

    @k8s_version.setter
    def k8s_version(self, k8s_version):
        """Sets the k8s_version of this KubernetesNodePoolPropertiesForPost.

        The Kubernetes version running in the node pool. Note that this imposes restrictions on which Kubernetes versions can run in the node pools of a cluster. Also, not all Kubernetes versions are suitable upgrade targets for all earlier versions.  # noqa: E501

        :param k8s_version: The k8s_version of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type k8s_version: str
        """

        self._k8s_version = k8s_version

    @property
    def labels(self):
        """Gets the labels of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The labels attached to the node pool.  # noqa: E501

        :return: The labels of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this KubernetesNodePoolPropertiesForPost.

        The labels attached to the node pool.  # noqa: E501

        :param labels: The labels of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type labels: dict(str, str)
        """

        self._labels = labels

    @property
    def lans(self):
        """Gets the lans of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The array of existing private LANs to attach to worker nodes.  # noqa: E501

        :return: The lans of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: list[KubernetesNodePoolLan]
        """
        return self._lans

    @lans.setter
    def lans(self, lans):
        """Sets the lans of this KubernetesNodePoolPropertiesForPost.

        The array of existing private LANs to attach to worker nodes.  # noqa: E501

        :param lans: The lans of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type lans: list[KubernetesNodePoolLan]
        """

        self._lans = lans

    @property
    def maintenance_window(self):
        """Gets the maintenance_window of this KubernetesNodePoolPropertiesForPost.  # noqa: E501


        :return: The maintenance_window of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: KubernetesMaintenanceWindow
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """Sets the maintenance_window of this KubernetesNodePoolPropertiesForPost.


        :param maintenance_window: The maintenance_window of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type maintenance_window: KubernetesMaintenanceWindow
        """

        self._maintenance_window = maintenance_window

    @property
    def name(self):
        """Gets the name of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        A Kubernetes node pool name. Valid Kubernetes node pool name must be 63 characters or less and must be empty or begin and end with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and alphanumerics between.  # noqa: E501

        :return: The name of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this KubernetesNodePoolPropertiesForPost.

        A Kubernetes node pool name. Valid Kubernetes node pool name must be 63 characters or less and must be empty or begin and end with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and alphanumerics between.  # noqa: E501

        :param name: The name of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def node_count(self):
        """Gets the node_count of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The number of worker nodes of the node pool.  # noqa: E501

        :return: The node_count of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: int
        """
        return self._node_count

    @node_count.setter
    def node_count(self, node_count):
        """Sets the node_count of this KubernetesNodePoolPropertiesForPost.

        The number of worker nodes of the node pool.  # noqa: E501

        :param node_count: The node_count of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type node_count: int
        """
        if self.local_vars_configuration.client_side_validation and node_count is None:  # noqa: E501
            raise ValueError("Invalid value for `node_count`, must not be `None`")  # noqa: E501

        self._node_count = node_count

    @property
    def public_ips(self):
        """Gets the public_ips of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        Optional array of reserved public IP addresses to be used by the nodes. The IPs must be from the exact location of the node pool's data center. If autoscaling is used, the array must contain one more IP than the maximum possible number of nodes (nodeCount+1 for a fixed number of nodes or maxNodeCount+1). The extra IP is used when the nodes are rebuilt.  # noqa: E501

        :return: The public_ips of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: list[str]
        """
        return self._public_ips

    @public_ips.setter
    def public_ips(self, public_ips):
        """Sets the public_ips of this KubernetesNodePoolPropertiesForPost.

        Optional array of reserved public IP addresses to be used by the nodes. The IPs must be from the exact location of the node pool's data center. If autoscaling is used, the array must contain one more IP than the maximum possible number of nodes (nodeCount+1 for a fixed number of nodes or maxNodeCount+1). The extra IP is used when the nodes are rebuilt.  # noqa: E501

        :param public_ips: The public_ips of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type public_ips: list[str]
        """

        self._public_ips = public_ips

    @property
    def ram_size(self):
        """Gets the ram_size of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The RAM size for the nodes. Must be specified in multiples of 1024 MB, with a minimum size of 2048 MB.  # noqa: E501

        :return: The ram_size of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: int
        """
        return self._ram_size

    @ram_size.setter
    def ram_size(self, ram_size):
        """Sets the ram_size of this KubernetesNodePoolPropertiesForPost.

        The RAM size for the nodes. Must be specified in multiples of 1024 MB, with a minimum size of 2048 MB.  # noqa: E501

        :param ram_size: The ram_size of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type ram_size: int
        """
        if self.local_vars_configuration.client_side_validation and ram_size is None:  # noqa: E501
            raise ValueError("Invalid value for `ram_size`, must not be `None`")  # noqa: E501

        self._ram_size = ram_size

    @property
    def storage_size(self):
        """Gets the storage_size of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The allocated volume size in GB. The allocated volume size in GB. To achieve good performance, we recommend a size greater than 100GB for SSD.  # noqa: E501

        :return: The storage_size of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: int
        """
        return self._storage_size

    @storage_size.setter
    def storage_size(self, storage_size):
        """Sets the storage_size of this KubernetesNodePoolPropertiesForPost.

        The allocated volume size in GB. The allocated volume size in GB. To achieve good performance, we recommend a size greater than 100GB for SSD.  # noqa: E501

        :param storage_size: The storage_size of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type storage_size: int
        """
        if self.local_vars_configuration.client_side_validation and storage_size is None:  # noqa: E501
            raise ValueError("Invalid value for `storage_size`, must not be `None`")  # noqa: E501

        self._storage_size = storage_size

    @property
    def storage_type(self):
        """Gets the storage_type of this KubernetesNodePoolPropertiesForPost.  # noqa: E501

        The storage type for the nodes.  # noqa: E501

        :return: The storage_type of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this KubernetesNodePoolPropertiesForPost.

        The storage type for the nodes.  # noqa: E501

        :param storage_type: The storage_type of this KubernetesNodePoolPropertiesForPost.  # noqa: E501
        :type storage_type: str
        """
        if self.local_vars_configuration.client_side_validation and storage_type is None:  # noqa: E501
            raise ValueError("Invalid value for `storage_type`, must not be `None`")  # noqa: E501
        allowed_values = ["HDD", "SSD"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and storage_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `storage_type` ({0}), must be one of {1}"  # noqa: E501
                .format(storage_type, allowed_values)
            )

        self._storage_type = storage_type
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KubernetesNodePoolPropertiesForPost):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KubernetesNodePoolPropertiesForPost):
            return True

        return self.to_dict() != other.to_dict()
